@@ -590,12 +590,37 @@ gint input_keypress(GtkObject *entry, GdkEventKey *event, gpointer data)
 			inputbox_ok(NULL, NULL);
 			Xdialog.exit_code = 0;
 		}
+		if (Xdialog.check) {
+			if (Xdialog.checked)
+				fprintf(Xdialog.output, "checked\n");
+			else
+				fprintf(Xdialog.output, "unchecked\n");
+		}
 		gtk_widget_destroy(Xdialog.window);
 		return FALSE;
 	}
 	return TRUE;
 }
 
+gboolean hide_passwords(GtkObject *button, gpointer data)
+{
+	gint entries;
+	gboolean visible;
+
+	entries = 1 + (Xdialog.widget2 != NULL ? 1 : 0) + (Xdialog.widget3 != NULL ? 1 : 0);
+
+	visible = (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)) == FALSE);
+
+	if (Xdialog.passwd >= entries)
+		gtk_entry_set_visibility(GTK_ENTRY(Xdialog.widget1), visible);
+	if (Xdialog.passwd >= entries-1 && entries > 1)
+		gtk_entry_set_visibility(GTK_ENTRY(Xdialog.widget2), visible);
+	if (Xdialog.passwd > 0 && entries > 2)
+		gtk_entry_set_visibility(GTK_ENTRY(Xdialog.widget3), visible);
+
+	return TRUE;
+}
+
 /* editbox callback */
 
 gboolean editbox_ok(gpointer object, gpointer data)
