@@ -998,6 +998,7 @@ void create_inputbox(gchar *optarg, gchar *options[], gint entries)
 {
 	GtkEntry *entry;
 	GtkWidget *button_ok = NULL;
+	GtkWidget *hide_button;
 	gchar deftext[MAX_INPUT_DEFAULT_LENGTH];
 
 	open_window();
@@ -1020,8 +1021,6 @@ void create_inputbox(gchar *optarg, gchar *options[], gint entries)
 	entry = GTK_ENTRY(Xdialog.widget1);
 	gtk_signal_connect(GTK_OBJECT(Xdialog.widget1), "key_press_event",
 			   GTK_SIGNAL_FUNC(input_keypress), NULL);
-	if (Xdialog.passwd >= entries)
-		gtk_entry_set_visibility(entry, FALSE);
 	gtk_entry_set_text(entry, deftext);
 	gtk_box_pack_start(Xdialog.vbox, Xdialog.widget1, TRUE, TRUE, 0);
 	gtk_widget_grab_focus(Xdialog.widget1);
@@ -1034,8 +1033,6 @@ void create_inputbox(gchar *optarg, gchar *options[], gint entries)
 		entry = GTK_ENTRY(Xdialog.widget2);
 		gtk_signal_connect(GTK_OBJECT(Xdialog.widget2), "key_press_event",
 				   GTK_SIGNAL_FUNC(input_keypress), NULL);
-		if (Xdialog.passwd >= entries - 1)
-			gtk_entry_set_visibility(entry, FALSE);
 		gtk_entry_set_text(entry, options[3]);
 		gtk_box_pack_start(Xdialog.vbox, Xdialog.widget2, TRUE, TRUE, 0);
 		gtk_widget_show(Xdialog.widget2);
@@ -1049,14 +1046,21 @@ void create_inputbox(gchar *optarg, gchar *options[], gint entries)
 		entry = GTK_ENTRY(Xdialog.widget3);
 		gtk_signal_connect(GTK_OBJECT(Xdialog.widget3), "key_press_event",
 				   GTK_SIGNAL_FUNC(input_keypress), NULL);
-		if (Xdialog.passwd > 0)
-			gtk_entry_set_visibility(entry, FALSE);
 		gtk_entry_set_text(entry, options[5]);
 		gtk_box_pack_start(Xdialog.vbox, Xdialog.widget3, TRUE, TRUE, 0);
 		gtk_widget_show(Xdialog.widget3);
 	} else
 		Xdialog.widget3 = NULL;
 
+	if (Xdialog.passwd > 0) {
+		hide_button = gtk_check_button_new_with_label(HIDE_TYPING);
+		gtk_box_pack_start(Xdialog.vbox, hide_button, TRUE, TRUE, 0);
+		gtk_widget_show(hide_button);
+		gtk_signal_connect(GTK_OBJECT(hide_button), "toggled",
+				   GTK_SIGNAL_FUNC(hide_passwords), NULL);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(hide_button), TRUE);
+	}
+
 	if (Xdialog.buttons) {
 		button_ok = set_all_buttons(FALSE, TRUE);
 		gtk_signal_connect(GTK_OBJECT(button_ok), "clicked", GTK_SIGNAL_FUNC(inputbox_ok), NULL);
